package webapi

import (
	"fmt"
	"log"
	"net/http"

	"gitea.nehmer.net/torben/dyndns/service"
	"github.com/gorilla/mux"
	"golang.org/x/crypto/bcrypt"
)

func Server() {
	r := mux.NewRouter()
	r.StrictSlash(true)

	r.HandleFunc("/hello", handleHello)
	r.HandleFunc("/update", handleDNSUpdate)

	log.Printf("Listening to: %s", C.ListenAddress)
	go log.Fatal(http.ListenAndServe(C.ListenAddress, r))
}

func handleHello(w http.ResponseWriter, r *http.Request) {
	r.ParseForm()
	log.Printf("handleHello %s", r.Host)
	log.Println(r.URL)
	log.Println(r.Form.Get("Lorem"))
	log.Println(r.Form)
	fmt.Fprint(w, "<html><body><p>Hello World</p></body></html>")
}

func handleDNSUpdate(w http.ResponseWriter, r *http.Request) {
	err := r.ParseForm()
	if err != nil {
		http.Error(w, err.Error(), http.StatusBadRequest)
		return
	}

	ur, err := createUpdateRequestFromForm(r.Form)
	if err != nil {
		http.Error(w, err.Error(), http.StatusBadRequest)
		return
	}

	v, err := service.LoadConfigForUser(ur.UserName)
	if err != nil {
		http.Error(w, err.Error(), http.StatusInternalServerError)
		return
	}

	w.Header().Set("Content-Type", "text/plain")
	fmt.Fprintln(w, "OK")
	fmt.Fprintln(w, ur.PrettyPrint())
	log.Println(ur.PrettyPrint())
	log.Println(ur.IPv6Net.IP)
	log.Println(ur.IPv6Net.Mask)
	log.Println(v.AllSettings())
	log.Printf("Request PW: %s, Config PW: %s", ur.Password, v.GetString("password"))

	err = bcrypt.CompareHashAndPassword([]byte(v.GetString("password")), []byte(ur.Password))
	log.Printf("PW Compare Result: %v", err)
}
